==> moodle-3.3.8.zip: moodle/grade/import/direct/lang/en/gradeimport_direct.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'gradeimport_direct', language 'en', branch 'MOODLE_28_STABLE'
 *
 * @package   gradeimport_direct
 * @copyright 2014 Adrian Greeve <adrian@moodle.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['direct:view'] = 'Import grades from CSV';
$string['pluginname'] = 'Paste from spreadsheet';
$string['privacy:metadata'] = 'The import grades from copied spreadsheed plugin does not store any personal data.';
$string['userdata'] = 'Help copying data into this form.';
$string['userdata_help'] = 'Grades may be copied and pasted from a spreadsheet into the gradebook. The spreadsheet should have a column containing user identity data - either username or ID number or email address. Each column for import should have a column header.';
$string['userdata_link'] = 'grade/import/direct/index';

==> moodle-4.5.1.zip: moodle/grade/import/direct/lang/en/gradeimport_direct.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'gradeimport_direct', language 'en', branch 'MOODLE_28_STABLE'
 *
 * @package   gradeimport_direct
 * @copyright 2014 Adrian Greeve <adrian@moodle.com>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['direct:view'] = 'Import grades from spreadsheet';
$string['pluginname'] = 'Paste from spreadsheet';
$string['privacy:metadata'] = 'The import grades from copied spreadsheed plugin does not store any personal data.';
$string['userdata'] = 'Help copying data into this form.';
$string['userdata_help'] = 'Grades may be copied and pasted from a spreadsheet into the gradebook. The spreadsheet should have a column containing user identity data - either username or ID number or email address. Each column for import should have a column header.';
$string['userdata_link'] = 'grade/import/direct/index';
